import UIKit
import Flutter
import Appier

@UIApplicationMain
@objc class AppDelegate: FlutterAppDelegate {
  override func application(
    _ application: UIApplication,
    didFinishLaunchingWithOptions launchOptions: [UIApplication.LaunchOptionsKey: Any]?
  ) -> Bool {
    GeneratedPluginRegistrant.register(with: self)
    
    // Registering Push Notification
        if #available(iOS 10.0, *) {
          let center = UNUserNotificationCenter.current()
          center.delegate = self
          center.requestAuthorization(options: [.badge, .carPlay, .alert, .sound]) { (granted, error) in
            print("Granted: \(granted), Error: \(String(describing: error))")
          }
        } else {
          // Fallback on earlier versions - iOS 8 & 9
          let settings = UIUserNotificationSettings(types: [.alert, .badge, .sound], categories: nil)
          UIApplication.shared.registerUserNotificationSettings(settings)
        }
    
    return super.application(application, didFinishLaunchingWithOptions: launchOptions)
  }
    
    // add these delegate methods to your AppDelegate class
    override func application(_ application: UIApplication, didRegisterForRemoteNotificationsWithDeviceToken deviceToken: Data) {
      let QG = QGSdk.getSharedInstance()
      print("My token is: \(deviceToken.description)")
      QG.setToken(deviceToken as Data)
    }

    override func application(_ application: UIApplication, didFailToRegisterForRemoteNotificationsWithError error: Error) {
      print("Failed to get token, error: \(error.localizedDescription)")
    }
    
    // handling the click and deeplink events from push notification
    @available(iOS 10.0, *)
    override func userNotificationCenter(_ center: UNUserNotificationCenter, didReceive response: UNNotificationResponse, withCompletionHandler completionHandler:@escaping() -> Void) {
      QGSdk.getSharedInstance().userNotificationCenter(center, didReceive: response)
      completionHandler()
    }
    
    // used for silent push handling
    // pass completion handler UIBackgroundFetchResult accordingly
    override func application(_ application: UIApplication, didReceiveRemoteNotification userInfo: [AnyHashable : Any], fetchCompletionHandler completionHandler: @escaping (UIBackgroundFetchResult) -> Void) {
      let QG = QGSdk.getSharedInstance()
      QG.application(application, didReceiveRemoteNotification: userInfo)
      completionHandler(UIBackgroundFetchResult.noData)
    }
    
    @available(iOS 10.0, *)
    override func userNotificationCenter(_ center: UNUserNotificationCenter, willPresent notification: UNNotification, withCompletionHandler completionHandler: @escaping (UNNotificationPresentationOptions) -> Void) {
      QGSdk.getSharedInstance().userNotificationCenter(center, willPresent: notification)
      completionHandler([.alert, .badge, .sound]);
    }
    
}
