// ignore_for_file: avoid_dynamic_calls

import 'dart:async';
import 'dart:io';

import 'package:appier_flutter/appier_flutter.dart';
import 'package:circular_menu/circular_menu.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_inappwebview/flutter_inappwebview.dart';
import 'package:package_info_plus/package_info_plus.dart';

import 'screens/event_screen.dart';
import 'screens/permission_screen.dart';
import 'screens/recommendation_screen.dart';
import 'screens/webview_screen.dart';

Future main() async {
  WidgetsFlutterBinding.ensureInitialized();
  await addSelfSignedCertificate();

  if (Platform.isAndroid) {
    await AndroidInAppWebViewController.setWebContentsDebuggingEnabled(true);
  }

  runApp(MainApp());
}

class MainApp extends StatefulWidget {
  const MainApp({Key? key}) : super(key: key);

  @override
  _MainAppState createState() => _MainAppState();
}

// add your app id before running in iOS
const appId = 'ab68caede8d777408f18';
// add your app group before running in iOS
const appGroup = 'group.com.appier.appierFlutterExample.notification';
const appUniversalLink = 'universal-link';

class _MainAppState extends State<MainApp> {
  PackageInfo _packageInfo = PackageInfo(
    appName: 'Unknown',
    packageName: 'Unknown',
    version: 'Unknown',
    buildNumber: 'Unknown',
    buildSignature: 'Unknown',
  );
  @override
  void initState() {
    super.initState();
    _initPackageInfo();
    AppierFlutter.configure(appId, appGroup: appGroup, isDev: true);
  }

  Future<void> _initPackageInfo() async {
    final info = await PackageInfo.fromPlatform();
    setState(() {
      _packageInfo = info;
    });
  }

  int _selectedIndex = 0;
  final List<Widget> _widgetOptions = <Widget>[
    EventWidget(),
    PermissionWidget(),
    RecommendationWidget(),
    WebviewWidget(),
  ];

  void _onItemTapped(int index) {
    setState(() {
      _selectedIndex = index;
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
        debugShowCheckedModeBanner: false,
        home: Scaffold(
          appBar: AppBar(
            title: Text(
                'Flutter Test App ${_packageInfo.version}+${_packageInfo.buildNumber}'),
          ),
          body: Center(
            child: _widgetOptions.elementAt(_selectedIndex),
          ),
          bottomNavigationBar: BottomNavigationBar(
            items: const <BottomNavigationBarItem>[
              BottomNavigationBarItem(
                icon: Icon(Icons.library_books),
                label: 'Events',
              ),
              BottomNavigationBarItem(
                icon: Icon(Icons.lock),
                label: 'Permissions',
              ),
              BottomNavigationBarItem(
                icon: Icon(Icons.widgets),
                label: 'Rec',
              ),
              BottomNavigationBarItem(
                icon: Icon(Icons.web),
                label: 'WebView',
              ),
            ],
            currentIndex: _selectedIndex,
            backgroundColor: Colors.black,
            unselectedItemColor: Colors.white,
            type: BottomNavigationBarType.fixed,
            onTap: _onItemTapped,
          ),
          floatingActionButton: CircularMenu(
            alignment: Alignment.bottomRight,
            toggleButtonColor: Colors.blue,
            items: [
              CircularMenuItem(
                  icon: Icons.cloud_upload,
                  color: Colors.green,
                  onTap: () {
                    //Add the action you want here.
                  }),
              CircularMenuItem(
                  icon: Icons.drive_file_rename_outline,
                  color: Colors.blue,
                  onTap: () {
                    AppierFlutter.setUniversalLinkDomains([]);
                    AppierFlutter.setUniversalLinkDomains([appUniversalLink]);
                  }),
            ],
          ),
        ));
  }
}

Future<void> addSelfSignedCertificate() async {
  try {
    final data = await rootBundle.load('assets/certificate.pem');
    SecurityContext.defaultContext
        .setTrustedCertificatesBytes(<int>[...data.buffer.asUint8List()]);
    print('Added certificate!');
    // ignore: avoid_catches_without_on_clauses
  } catch (e) {
    print(e);
  }
}
