import 'dart:io';

import 'package:app_tracking_transparency/app_tracking_transparency.dart';
import 'package:appier_flutter/appier_flutter.dart';
import 'package:flutter/material.dart';
import 'package:permission_handler/permission_handler.dart';

const appUniversalLink = 'universal-link';

class PermissionWidget extends StatefulWidget {
  const PermissionWidget({Key? key}) : super(key: key);

  @override
  _PermissionWidgetState createState() => _PermissionWidgetState();
}

class _PermissionWidgetState extends State<PermissionWidget> {
  @override
  void initState() {
    super.initState();
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Center(
      child: ListView(
        padding: EdgeInsets.all(8),
        children: <Widget>[
          SizedBox(
            height: 44,
            child: ElevatedButton(
              style: ElevatedButton.styleFrom(
                primary: Colors.teal[200],
                onPrimary: Colors.black,
              ),
              onPressed: Platform.isIOS
                  ? () async {
                      await _showMyDialog('Check ATT status',
                          '${await AppTrackingTransparency.trackingAuthorizationStatus}');
                    }
                  : null,
              child: Text('Check ATT status'),
            ),
          ),
          SizedBox(
            height: 44,
            child: ElevatedButton(
              style: ElevatedButton.styleFrom(
                primary: Colors.teal[100],
                onPrimary: Colors.black,
              ),
              onPressed: Platform.isIOS
                  ? () async {
                      final status = await AppTrackingTransparency
                          .requestTrackingAuthorization();
                      await _showMyDialog(
                          'Request ATT authorization', '$status');
                    }
                  : null,
              child: Text('Request ATT authorization'),
            ),
          ),
          SizedBox(
            height: 44,
            child: ElevatedButton(
              style: ElevatedButton.styleFrom(
                primary: Colors.teal[200],
                onPrimary: Colors.black,
              ),
              onPressed: Platform.isIOS
                  ? () {
                      AppierFlutter.enableIdfaConsent();
                      _showMyDialog('IDFA Consent', 'Enabled');
                    }
                  : null,
              child: Text('Enable IDFA consent in SDK'),
            ),
          ),
          SizedBox(
            height: 44,
            child: ElevatedButton(
              style: ElevatedButton.styleFrom(
                primary: Colors.teal[100],
                onPrimary: Colors.black,
              ),
              onPressed: Platform.isIOS
                  ? () {
                      AppierFlutter.disableIdfaConsent();
                      _showMyDialog('IDFA Consent', 'Disabled');
                    }
                  : null,
              child: Text('Disable IDFA consent in SDK'),
            ),
          ),
          SizedBox(
            height: 44,
            child: ElevatedButton(
              style: ElevatedButton.styleFrom(
                primary: Colors.teal[200],
                onPrimary: Colors.black,
              ),
              onPressed: Platform.isAndroid
                  ? () async {
                      final phoneStatue = await Permission.phone.request();
                      if (phoneStatue.isGranted) {
                        await _showMyDialog('Permission granted.', '');
                        return;
                      } else if (phoneStatue.isDenied ||
                          phoneStatue.isPermanentlyDenied) {
                        await _showMyDialog('Permission denied.', '');
                        return;
                      }
                    }
                  : null,
              child: Text('Request Android READ_PHONE_STATE'),
            ),
          ),
        ],
      ),
    );
  }

  Future<void> _showMyDialog(String title, String content) async {
    return showDialog<void>(
      context: context,
      barrierDismissible: false, // user must tap button!
      builder: (context) {
        return AlertDialog(
          title: Text(title),
          content: SingleChildScrollView(
            child: Text(content),
          ),
          actions: <Widget>[
            TextButton(
              onPressed: () {
                Navigator.of(context).pop();
              },
              child: Text('OK'),
            ),
          ],
        );
      },
    );
  }
}
